@@ -1,6 +1,6 @@
 ###############################################################################
 #
-#   Copyright (c) 2000, 2001, 2002  Randy J. Ray <rjray@blackperl.com>
+#   Copyright (c) 2000, 2001, 2002, 2007  Randy J. Ray <rjray@blackperl.com>
 #             (c) 2006, 2007  Alexey Tourbin <at@altlinux.org>
 #   All Rights Reserved
 #
@@ -31,10 +31,12 @@ use strict;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD);
 use subs qw(new AUTOLOAD filenames);
 
-use RPM; $VERSION = $RPM::VERSION;
+use RPM;
 use RPM::Error;
 use RPM::Constants ':rpmerr';
 
+$VERSION = '1.21';
+
 1;
 
 sub new
